==> 0.5.6.tar.gz: lib/widget/vgk-title-widget/vgk-title-with-animation-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkTitleWithAnimationWidget extends StatelessWidget {
  final String titleTxt;
  final String subTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  final TextStyle subTitlefontSize;
  const VgkTitleWithAnimationWidget({
    this.titleTxt: "",
    this.subTxt: "",
    this.animationController,
    this.animation,
    this.color,
    this.titlefontSize,
    this.subTitlefontSize,
  }) : super();

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Container(
              child: Padding(
                padding: const EdgeInsets.only(
                  left: VgkProGamingTheme.paddingDoubleExtraLarge,
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Row(
                  children: <Widget>[
                    Expanded(
                      child: Text(
                        titleTxt,
                        textAlign: TextAlign.left,
                        style: titlefontSize != null
                            ? titlefontSize
                            : VgkProGamingTheme.h1,
                      ),
                    ),
                    titleViewSubConent(subTxt, subTitlefontSize)
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  Widget titleViewSubConent(input, subTitlefontSize) {
    if (input != null && input != '') {
      return InkWell(
        highlightColor: Colors.transparent,
        borderRadius: BorderRadius.all(Radius.circular(4.0)),
        onTap: () {},
        child: Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Row(
            children: <Widget>[
              Text(
                subTxt,
                textAlign: TextAlign.left,
                style: subTitlefontSize != null
                    ? subTitlefontSize
                    : VgkProGamingTheme.h3,
              ),
              SizedBox(
                height: 38,
                width: 26,
                child: Icon(
                  Icons.arrow_forward,
                  color: VgkProGamingTheme.darkText,
                  size: 18,
                ),
              ),
            ],
          ),
        ),
      );
    } else {
      return Container();
    }
  }
}

==> 0.9.5.tar.gz: lib/widget/vgk-title-widget/vgk-title-with-animation-widget.dart <==
import 'package:flutter/material.dart';
import 'package:vgkprogaming/theme/vgk-shared-theme.dart';

class VgkTitleWithAnimationWidget extends StatelessWidget {
  final String titleTxt;
  final String subTxt;
  final AnimationController animationController;
  final Animation animation;
  final MaterialColor color;
  final TextStyle titlefontSize;
  final TextStyle subTitlefontSize;
  final String primaryColor;
  const VgkTitleWithAnimationWidget({
    this.titleTxt: "",
    this.subTxt: "",
    this.animationController,
    this.animation,
    this.color,
    this.titlefontSize,
    this.subTitlefontSize,
    this.primaryColor,
  }) : super();

  @override
  Widget build(BuildContext context) {
    return AnimatedBuilder(
      animation: animationController,
      builder: (BuildContext context, Widget child) {
        return FadeTransition(
          opacity: animation,
          child: new Transform(
            transform: VgkProGamingTheme.transform(animation),
            child: Container(
              child: Padding(
                padding: const EdgeInsets.only(
                  left: VgkProGamingTheme.paddingDoubleExtraLarge,
                  right: VgkProGamingTheme.paddingDoubleExtraLarge,
                ),
                child: Row(
                  children: <Widget>[
                    Expanded(
                      child: Text(
                        titleTxt,
                        textAlign: TextAlign.left,
                        style: titlefontSize != null
                            ? titlefontSize
                            : VgkProGamingTheme.h1(primaryColor),
                      ),
                    ),
                    titleViewSubConent(subTxt, subTitlefontSize)
                  ],
                ),
              ),
            ),
          ),
        );
      },
    );
  }

  Widget titleViewSubConent(input, subTitlefontSize) {
    if (input != null && input != '') {
      return InkWell(
        highlightColor: Colors.transparent,
        borderRadius: BorderRadius.all(Radius.circular(4.0)),
        onTap: () {},
        child: Padding(
          padding: const EdgeInsets.only(left: 8),
          child: Row(
            children: <Widget>[
              Text(
                subTxt,
                textAlign: TextAlign.left,
                style: subTitlefontSize != null
                    ? subTitlefontSize
                    : VgkProGamingTheme.h3(primaryColor),
              ),
              SizedBox(
                height: 38,
                width: 26,
                child: Icon(
                  Icons.arrow_forward,
                  color: VgkProGamingTheme.darkText,
                  size: 18,
                ),
              ),
            ],
          ),
        ),
      );
    } else {
      return Container();
    }
  }
}
